#ifndef __M200_WIRING_H__
#define __M200_WIRING_H__

/**
 * AVR M200 Punch card reader controller
 * Wiring constants
 *
 * Defined symbols for the wiring of the uC on our board.
 * This is *very* specific to our hardware setup.
 *
 * This file is part of the Punched Paper Project - Punch Card Device Drivers
 * Copyright (C) 2009  Sven Koeppel
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see
 * <http://www.gnu.org/licenses/>.
 *
 *
 **/

#include "avr/io.h"
#include "avr/interrupt.h"

// pracitcal utilities
#define check(where, what) ( ((what) & (where)) ? 1 : 0 )
#define check_pin(where, which) ( ((1 << (which)) & (where)) ? 1 : 0 )

// 1. Pin Input Names
//    (PINx registers for INPUT reading)

// Port Input A: Data
#define PINA_D0		PINA0
#define PINA_D1		PINA1
#define PINA_D2		PINA2
#define PINA_D3		PINA3
#define PINA_D4		PINA4
#define PINA_D5		PINA5
#define PINA_D6		PINA6
#define PINA_D7		PINA7

// Port Input B: Error, Button
#define PINB_BUT	PINB4
#define PINB_ERROR	PINB1
#define PINB_HCK	PINB2
#define PINB_MOCK	PINB3

// Port Input C: Error, Signals, Data
#define PINC_BSY	PINC7
#define PINC_RDY	PINC5
#define PINC_IM		PINC4
#define PINC_PC		PINC6  // only for reading in the current state
#define PINC_D8		PINC0
#define PINC_D9		PINC1
#define PINC_D11	PINC2
#define PINC_D12	PINC3

// Port Input D: (RS232 Hardware flow control)


// 2. Port Output Names
//    (PORTx registers for OUTPUT writing)

// Port Output B: LED
#define PORTB_LED	PORTB0

// Port Output C: Pick Command
#define PORTC_PC	PORTC6


// 3. Port Interrupts

// Pin Change Masks
#define PCINT_IM	PCINT20
#define PCINT_RDY	PCINT21
#define PCINT_ERROR	PCINT9
#define PCINT_HCK	PCINT10
#define PCINT_MOCK	PCINT11
#define PCINT_PC	PCINT22
#define PCINT_BSY	PCINT23

// 4. Output Lines

#define start_reader()	( PORTC |= (1 << PORTC_PC) )
#define stop_reader()	( PORTC &= ~(1 << PORTC_PC) )

// sic! mit ja/nein und so
#define start_led()		( PORTB &= ~(1 << PORTB_LED) )
#define stop_led()		( PORTB |= (1 << PORTB_LED) )

#endif /* __M200_WIRING_H__ */
